import logging
from decimal import Decimal

NUMBER_TYPES = (int, float, Decimal)

__version__ = "0.1.10"
__name__ = "calculation-mapilio"
__major__ = False
__minor__ = False
__patch__ = True


logger = logging.getLogger('calculation')

